|pypi| |actions| |codecov| |downloads|


effect-form-validators
----------------------

Form validator classes for EFFECT model forms

.. |pypi| image:: https://img.shields.io/pypi/v/effect-form-validators.svg
    :target: https://pypi.python.org/pypi/effect-form-validators

.. |actions| image:: https://github.com/effect-trial/effect-form-validators/workflows/build/badge.svg?branch=develop
  :target: https://github.com/effect-trial/effect-form-validators/actions?query=workflow:build

.. |codecov| image:: https://codecov.io/gh/effect-trial/effect-form-validators/branch/develop/graph/badge.svg
  :target: https://codecov.io/gh/effect-trial/effect-form-validators

.. |downloads| image:: https://pepy.tech/badge/effect-form-validators
   :target: https://pepy.tech/project/effect-form-validators
